==> nextcloud-21.0.0-7-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/ko.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "개인 정보 취급 방침",
    "-" : "-",
    "Add external admin" : "외부 관리자 추가",
    "This server is using full-disk-encryption." : "이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "Your files are not protected by encryption." : "파일이 더 이상 암호화로 보호되지 않습니다.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "파일이 {linkopen}서버 측 암호화 ↗{linkclose}로 보호됩니다.",
    "This server is protected with full-disk-encryption." : "이 서버는 전체 디스크 암호화로 보호됩니다.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "파일이 {linkopen}서버 측 암호화 ↗{linkclose}로 보호됩니다. 추가적으로 이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "Your data is located in: " : "귀하의 데이터는 여기에 있습니다:",
    "The admin hasn't selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
    "You don't have any shares with individual users." : "개인 사용자와 공유한 항목이 없습니다.",
    "Andorra" : "안도라",
    "Afghanistan" : "아프가니스탄",
    "Anguilla" : "앵귈라",
    "Albania" : "알바니아",
    "Angola" : "앙골라",
    "Antarctica" : "남극",
    "Argentina" : "아르헨티나",
    "American Samoa" : "미국령 사모아",
    "Austria" : "오스트리아",
    "Australia" : "오스트레일리아",
    "Åland Islands" : "올란드 제도",
    "Brazil" : "브라질",
    "Bhutan" : "부탄",
    "Canada" : "캐나다",
    "China" : "중국",
    "Algeria" : "알제리",
    "Japan" : "일본",
    "Singapore" : "싱가포르",
    "Your Nextcloud account" : "내 Nextcloud 계정",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "내 데이터를 통해서 개인을 식별할 수 있고 쉽게 잘못 사용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터를 사용할 방법을 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "인터넷에서 사람들의 데이터를 제어하는 기본 권리 선언",
    "Control" : "제어:",
    "over user data access" : "사용자 데이터 접근",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "사용자가 직접 명시적으로 업로드한 데이터는 사용자의 제어 하에 있어야 합니다. 사용자는 누가 데이터에 직접 접근하고, 어떤 권한과 라이선스로 접근을 허가할지 결정할 수 있습니다.",
    "Knowledge" : "지식:",
    "of how the data is stored" : "데이터 저장 방법",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "데이터를 서비스 공급자에 업로드했을 때 사용자는 서비스 공급자가 어디에 데이터를 저장하고, 얼마 동안 데이터를 저장하고, 어느 지역에서 영업하며, 어떤 법률이 적용되는지 알아야 합니다.",
    "Freedom" : "자유:",
    "to choose a platform" : "플랫폼 선택",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "사용자는 언제든지 벤더 잠금 없이 서비스에서 데이터를 추출할 수 있어야 합니다. 이를 보장하려면 공개된 데이터 형식과 프로토콜이 필수적입니다.",
    "Learn more ↗" : "더 알아보기 ↗",
    "Where is your data?" : "내 데이터는 어디에 있나요?",
    "Who has access to your data?" : "누가 내 데이터에 접근할 수 있나요?",
    "Administrators" : "관리자",
    "People you shared with" : "공유한 다른 사람",
    "Privacy policy" : "개인 정보 취급 방침",
    "Read the privacy policy." : "개인 정보 취급 방침을 읽습니다.",
    "Encryption" : "암호화"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/ko.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "개인 정보 취급 방침",
    "-" : "-",
    "Add external admin" : "외부 관리자 추가",
    "This server is using full-disk-encryption." : "이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "Your files are not protected by encryption." : "파일이 더 이상 암호화로 보호되지 않습니다.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "파일이 {linkopen}서버 측 암호화 ↗{linkclose}로 보호됩니다.",
    "This server is protected with full-disk-encryption." : "이 서버는 전체 디스크 암호화로 보호됩니다.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "파일이 {linkopen}서버 측 암호화 ↗{linkclose}로 보호됩니다. 추가적으로 이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
    "The admin hasn't selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
    "You don't have any shares with individual users." : "개인 사용자와 공유한 항목이 없습니다.",
    "Andorra" : "안도라",
    "Afghanistan" : "아프가니스탄",
    "Anguilla" : "앵귈라",
    "Albania" : "알바니아",
    "Angola" : "앙골라",
    "Antarctica" : "남극",
    "Argentina" : "아르헨티나",
    "American Samoa" : "미국령 사모아",
    "Austria" : "오스트리아",
    "Australia" : "오스트레일리아",
    "Åland Islands" : "올란드 제도",
    "Brazil" : "브라질",
    "Bhutan" : "부탄",
    "Canada" : "캐나다",
    "China" : "중국",
    "Algeria" : "알제리",
    "Japan" : "일본",
    "Singapore" : "싱가포르",
    "Your Nextcloud account" : "내 Nextcloud 계정",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "내 데이터를 통해서 개인을 식별할 수 있고 쉽게 잘못 사용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터를 사용할 방법을 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "인터넷에서 사람들의 데이터를 제어하는 기본 권리 선언",
    "Control" : "제어:",
    "over user data access" : "사용자 데이터 접근",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "사용자가 직접 명시적으로 업로드한 데이터는 사용자의 제어 하에 있어야 합니다. 사용자는 누가 데이터에 직접 접근하고, 어떤 권한과 라이선스로 접근을 허가할지 결정할 수 있습니다.",
    "Knowledge" : "지식:",
    "of how the data is stored" : "데이터 저장 방법",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "데이터를 서비스 공급자에 업로드했을 때 사용자는 서비스 공급자가 어디에 데이터를 저장하고, 얼마 동안 데이터를 저장하고, 어느 지역에서 영업하며, 어떤 법률이 적용되는지 알아야 합니다.",
    "Freedom" : "자유:",
    "to choose a platform" : "플랫폼 선택",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "사용자는 언제든지 벤더 잠금 없이 서비스에서 데이터를 추출할 수 있어야 합니다. 이를 보장하려면 공개된 데이터 형식과 프로토콜이 필수적입니다.",
    "Learn more ↗" : "더 알아보기 ↗",
    "Where is your data?" : "내 데이터는 어디에 있나요?",
    "Who has access to your data?" : "누가 내 데이터에 접근할 수 있나요?",
    "Administrators" : "관리자",
    "People you shared with" : "공유한 다른 사람",
    "Privacy policy" : "개인 정보 취급 방침",
    "Read the privacy policy." : "개인 정보 취급 방침을 읽습니다.",
    "Encryption" : "암호화",
    "Your data is located in: " : "귀하의 데이터는 여기에 있습니다:"
},
"nplurals=1; plural=0;");
